@@ -10,10 +10,10 @@ class SearchCrtsh:
     async def do_search(self) -> list:
         data: set = set()
         try:
-            url = f'https://crt.sh/?q=%25.{self.word}&output=json'
+            url = f'https://crt.sh/?q=%25.{self.word}&exclude=expired&deduplicate=Y&output=json'
             response = await AsyncFetcher.fetch_all([url], json=True, proxy=self.proxy)
             response = response[0]
-            data = set([dct['name_value'][2:] if '*.' == dct['name_value'][:2] else dct['name_value'] for dct in response])
+            data = set([(dct['name_value'][2:] if dct['name_value'][:2] == '*.' else dct['name_value']) for dct in response])
             data = {domain for domain in data if (domain[0] != '*' and str(domain[0:4]).isnumeric() is False)}
         except Exception as e:
             print(e)
