@@ -14,14 +14,14 @@ class SearchUrlscan:
         url = f'https://urlscan.io/api/v1/search/?q=domain:{self.word}'
         response = await AsyncFetcher.fetch_all([url], json=True, proxy=self.proxy)
         resp = response[0]
-        self.totalhosts = {f"{page['page']['domain']}" for page in resp['results']}
-        self.totalips = {f"{page['page']['ip']}" for page in resp['results'] if 'ip' in page['page'].keys()}
+        self.totalhosts = {f'{page["page"]["domain"]}' for page in resp['results']}
+        self.totalips = {f'{page["page"]["ip"]}' for page in resp['results'] if 'ip' in page['page'].keys()}
         self.interestingurls = {
-            f"{page['page']['url']}"
+            f'{page["page"]["url"]}'
             for page in resp['results']
             if self.word in page['page']['url'] and 'url' in page['page'].keys()
         }
-        self.totalasns = {f"{page['page']['asn']}" for page in resp['results'] if 'asn' in page['page'].keys()}
+        self.totalasns = {f'{page["page"]["asn"]}' for page in resp['results'] if 'asn' in page['page'].keys()}
 
     async def get_hostnames(self) -> set:
         return self.totalhosts
