@@ -11,7 +11,13 @@ def main():
         import multiprocessing
 
         multiprocessing.freeze_support()
-        asyncio.DefaultEventLoopPolicy = asyncio.WindowsSelectorEventLoopPolicy
+        try:
+            # See if we have winloop as a performance enhancement on windows
+            import winloop
+
+            asyncio.DefaultEventLoopPolicy = winloop.EventLoopPolicy
+        except ModuleNotFoundError:
+            asyncio.DefaultEventLoopPolicy = asyncio.WindowsSelectorEventLoopPolicy
     else:
         import uvloop
 
